import SwiftUI

extension Color {
    init(hex: String) {
        let scanner = Scanner(string: hex)
        var hexValue: UInt64 = 0
        scanner.scanHexInt64(&hexValue)
        self.init(
            red: Double((hexValue >> 16) & 0xFF) / 255.0,
            green: Double((hexValue >> 8) & 0xFF) / 255.0,
            blue: Double(hexValue & 0xFF) / 255.0,
            opacity: 1.0
        )
    }
    
    var variation: Color {
        self.mix(with: .black, by: 0.1)
    }
}

extension Date {
    var secondsElapsedSinceMidnight: Int {
        let calendar = Calendar.current
        let components = calendar.dateComponents([.hour, .minute, .second], from: self)
        return (components.hour ?? 0) * 3600 +
        (components.minute ?? 0) * 60 +
        (components.second ?? 0)
    }
}

extension Dictionary {
    func mapKeys<T: Hashable>(_ transform: (Key) -> T) -> [T: Value] {
        var newDict: [T: Value] = [:]
        for (key, value) in self {
            newDict[transform(key)] = value
        }
        return newDict
    }
    
    func mapValuesWithKey<T>(_ transform: (Key, Value) -> T) -> [Key: T] {
        var result: [Key: T] = [:]
        for (key, value) in self {
            result[key] = transform(key, value)
        }
        return result
    }
}

extension Sequence {
    func unique<T: Hashable>(by keySelector: (Element) -> T) -> [Element] {
        var seen = Set<T>()
        return self.filter { seen.insert(keySelector($0)).inserted }
    }
}

extension String {
    func toDate() -> Date? {
        let formatter = DateFormatter()
        formatter.dateFormat = "yyyyMMdd"
        return formatter.date(from: self)
    }
}
