import SwiftUI
import MapKit

func loadMapView() -> [CustomMapPolygon] {
    guard let url = Bundle.main.url(forResource: "map", withExtension: "geojson") else {
        print("GeoJSON not found!")
        return []
    }
    
    do {
        let data = try Data(contentsOf: url)
        let decoder = MKGeoJSONDecoder()
        let features = try decoder.decode(data)
        
        var loadedPolygons: [CustomMapPolygon] = []
        
        for feature in features {
            if let feature = feature as? MKGeoJSONFeature {
                for geometry in feature.geometry {
                    if let polygon = geometry as? MKPolygon {
                        let type: CustomMapElementType
                        if let properties = feature.properties,
                           let json = try? JSONSerialization.jsonObject(with: properties) as? [String: Any],
                           let rawType = json["type"] as? String {
                            switch rawType {
                            case "water":
                                type = .water
                            case "nature":
                                type = .nature
                            case "ground":
                                type = .ground
                            case "residential":
                                type = .residential
                            default:
                                type = .relief
                            }
                        } else {
                            type = .relief
                        }
                        
                        loadedPolygons.append(.init(polygon: polygon, type: type))
                    }
                }
            }
        }
        
        return loadedPolygons
    } catch {
        print(error.localizedDescription)
    }
    
    return []
}
